@@ -1,17 +1,17 @@
 # MIT License
-# 
-# Copyright (c) 2022 vn.py
-# 
+
+# Copyright (c) 2022-present Xiaoyou Chen
+
 # Permission is hereby granted, free of charge, to any person obtaining a copy
 # of this software and associated documentation files (the "Software"), to deal
 # in the Software without restriction, including without limitation the rights
 # to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 # copies of the Software, and to permit persons to whom the Software is
 # furnished to do so, subject to the following conditions:
-# 
+
 # The above copyright notice and this permission notice shall be included in all
 # copies or substantial portions of the Software.
-# 
+
 # THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 # IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 # FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
@@ -21,12 +21,10 @@
 # SOFTWARE.
 
 
-import importlib_metadata
-
-from .gm_gateway import GmGateway
+from .gm_datafeed import GmDatafeed as Datafeed
 
 
-try:
-    __version__ = importlib_metadata.version("vnpy_gm")
-except importlib_metadata.PackageNotFoundError:
-    __version__ = "dev"
\ No newline at end of file
+__all__ = ["Datafeed"]
+
+
+__version__ = "1.2.0"
